<?php
/**
 *
 * Copyright notice
 *
 * (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 * All rights reserved
 *
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 *
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * This copyright notice MUST APPEAR in all copies of the script!
 */

return call_user_func(
	function ($extKey, $table) {
		return [
			'ctrl' => [
				'title' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '',
				'label' => 'title',
				'tstamp' => 'tstamp',
				'crdate' => 'crdate',
				'cruser_id' => 'cruser_id',
				'dividers2tabs' => TRUE,
				'searchFields' => 'title, job_id, start_date, alternative_start_date, company, contact, department',
				'versioningWS' => 2,
				'versioning_followPages' => TRUE,
				'origUid' => 't3_origuid',
				'languageField' => 'sys_language_uid',
				'transOrigPointerField' => 'l10n_parent',
				'transOrigDiffSourceField' => 'l10n_diffsource',
				'delete' => 'deleted',
				'enablecolumns' => [
					'disabled' => 'hidden',
					'starttime' => 'starttime',
					'endtime' => 'endtime',
				],
				'sortby' => 'sorting',
				'iconfile' => 'EXT:' . $extKey . '/Resources/Public/Icons/' . $table . '.svg'
			],
			'interface' => [
				'showRecordFieldList' => 'sys_language_uid, l10n_parent, l10n_diffsource, hidden, pid, title, job_id, department, hide_apply_by_email, hide_apply_by_postal, featured_offer, start_date, alternative_start_date,
			 company, task, qualification, description, contact',
			],
			'types' => [
				'1' => [
					'showitem' => '--palette--;;sysLanguageAndHidden,title, job_id,
					--palette--;;palette_title_start,
					--palette--;;palette_apply_function,
					department,
					company,
					contact,
					description,
					--div--; LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:tca.qualification_tab, task, qualification,
					--div--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:tabs.access, starttime, endtime',
				],
			],
			'palettes' => [
				'sysLanguageAndHidden' => [
					'showitem' => 'sys_language_uid;;;;1-1-1, l10n_diffsource, hidden;;1, ',
					'canNotCollapse' => 1,
				],
				'palette_title_start' => ['showitem' => 'start_date, alternative_start_date', 'canNotCollapse' => 1],
				'palette_apply_function' => ['showitem' => 'hide_apply_by_email, hide_apply_by_postal, featured_offer', 'canNotCollapse' => 1]
			],
			'columns' => [
				'crdate' => [
					'exclude' => FALSE,
					'config' => [
						'type' => 'passthrough'
					]
				],
				'sys_language_uid' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.language',
					'config' => [
						'type' => 'select',
						'special' => 'languages',
					],
				],
				'l10n_parent' => [
					'displayCond' => 'FIELD:sys_language_uid:>:0',
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.l18n_parent',
					'config' => [
						'type' => 'select',
						'items' => [
							['', 0],
						],
						'foreign_table' => $table,
						'foreign_table_where' => 'AND ' . $table . '.pid=###CURRENT_PID### AND ' . $table . '.sys_language_uid IN (-1,0)',
					],
				],
				'l10n_diffsource' => [
					'config' => [
						'type' => 'passthrough',
					],
				],
				't3ver_label' => [
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.versionLabel',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'max' => 255,
					]
				],
				'pid' => [
					'exclude' => FALSE,
					'label' => 'PID',
					'config' => [
						'type' => 'none',
					]
				],
				'hidden' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.hidden',
					'config' => [
						'type' => 'check',
					],
				],
				'starttime' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.starttime',
					'config' => [
						'type' => 'input',
						'renderType' => 'inputDateTime',
						'eval' => 'datetime,int',
						'default' => 0
					],
					'l10n_mode' => 'exclude',
					'l10n_display' => 'defaultAsReadonly'
				],
				'endtime' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.endtime',
					'config' => [
						'type' => 'input',
						'renderType' => 'inputDateTime',
						'eval' => 'datetime,int',
						'default' => 0,
						'range' => [
							'upper' => mktime(0, 0, 0, 1, 1, 2038)
						]
					],
					'l10n_mode' => 'exclude',
					'l10n_display' => 'defaultAsReadonly'
				],
				'title' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.title',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'job_id' => [
					'exclude' => TRUE,
					'l10n_mode' => 'exclude',
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.jobId',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim'
					],
				],
				'department' => [
					'exclude' => TRUE,
					'l10n_mode' => 'exclude',
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.department',
					'config' => [
						'type' => 'select',
						'renderType' => 'selectMultipleSideBySide',
						'foreign_table' => 'tx_sgjobs_domain_model_department',
						'foreign_table_where' => ' AND (tx_sgjobs_domain_model_department.sys_language_uid=###REC_FIELD_sys_language_uid### OR tx_sgjobs_domain_model_department.sys_language_uid=-1) ORDER BY tx_sgjobs_domain_model_department.sorting ASC',
						'minitems' => 1,
						'maxitems' => 1,
						'size' => 1,
						'fieldControl' => [
							'editPopup' => [
								'disabled' => FALSE,
							],
							'addRecord' => [
								'disabled' => FALSE,
							]
						]
					],
				],
				'featured_offer' => [
					'exclude' => TRUE,
					'l10n_mode' => 'exclude',
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.featuredOffer',
					'config' => [
						'type' => 'check',
					],
				],
				'hide_apply_by_email' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.hideApplyByEmail',
					'config' => [
						'type' => 'check',
					],
				],
				'hide_apply_by_postal' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.hideApplyByPostal',
					'config' => [
						'type' => 'check',
					],
				],
				'start_date' => [
					'exclude' => TRUE,
					'l10n_mode' => 'exclude',
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.start_date',
					'config' => [
						'type' => 'input',
						'renderType' => 'inputDateTime',
						'size' => 13,
						'max' => 20,
						'eval' => 'date'
					],
				],
				'alternative_start_date' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.alternative_start_date',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim'
					],
				],
				'task' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.task',
					'config' => [
						'type' => 'text',
						'cols' => 40,
						'rows' => 10,
						'eval' => ''
					],
					'defaultExtras' => 'richtext[]'
				],
				'qualification' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.qualification',
					'config' => [
						'type' => 'text',
						'cols' => 40,
						'rows' => 10,
						'eval' => ''
					],
					'defaultExtras' => 'richtext[]'
				],
				'description' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.description',
					'config' => [
						'type' => 'text',
						'cols' => 40,
						'rows' => 10,
						'eval' => ''
					],
					'defaultExtras' => 'richtext[]'
				],
				'company' => [
					'exclude' => TRUE,
					'l10n_mode' => 'exclude',
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.company',
					'config' => [
						'type' => 'select',
						'renderType' => 'selectMultipleSideBySide',
						'foreign_table' => 'tx_sgjobs_domain_model_company',
						'foreign_table_where' =>  ' AND (tx_sgjobs_domain_model_company.sys_language_uid=###REC_FIELD_sys_language_uid### OR tx_sgjobs_domain_model_company.sys_language_uid=-1) ORDER BY tx_sgjobs_domain_model_company.sorting ASC',
						'size' => 1,
						'minitems' => 1,
						'maxitems' => 1,
						'multiple' => 0,
						'fieldControl' => [
							'editPopup' => [
								'disabled' => FALSE,
							],
							'addRecord' => [
								'disabled' => FALSE,
							]
						],
					]
				],
				'contact' => [
					'exclude' => TRUE,
					'l10n_mode' => 'exclude',
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.contact',
					'config' => [
						'type' => 'select',
						'renderType' => 'selectMultipleSideBySide',
						'foreign_table' => 'tx_sgjobs_domain_model_contact',
						'foreign_table_where' => ' AND (tx_sgjobs_domain_model_contact.sys_language_uid=###REC_FIELD_sys_language_uid### OR tx_sgjobs_domain_model_contact.sys_language_uid=-1) ORDER BY tx_sgjobs_domain_model_contact.sorting ASC',
						'size' => 1,
						'minitems' => 1,
						'maxitems' => 1,
						'multiple' => 0,
						'fieldControl' => [
							'editPopup' => [
								'disabled' => FALSE,
							],
							'addRecord' => [
								'disabled' => FALSE,
							]
						],
					]
				]
			],
		];
	}, 'sg_jobs', 'tx_sgjobs_domain_model_job'
);

